package com.house365.xxx.house.word.search.core;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import java.util.Set;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

import javax.annotation.Resource;

import org.apache.commons.lang.StringUtils;
import org.springframework.stereotype.Component;

import com.house365.xxx.house.word.search.dto.WordBean;
import com.house365.xxx.house.word.search.dto.WordRatio;
import com.house365.xxx.house.word.search.sell.BlockLoader;
import com.house365.xxx.house.word.search.sell.SchoolLoader;
import com.house365.xxx.house.word.search.sell.TrafficLoader;
import com.house365.xxx.house.word.search.util.PinyinToolkit;

@Component
public class DistanceChecker {
	// private static Log logger = LogFactory.getLog(DistanceChecker.class);
	@Resource
	private BlockLoader blockLoader;
	@Resource
	private SchoolLoader schoolLoader;
	@Resource
	private TrafficLoader trafficLoader;

	public void init() {
		blockLoader.loadWordBeans();
		schoolLoader.loadWordBeans();
		trafficLoader.loadWordBeans();
	}

	public List<WordRatio> getWordsFromBlock(String city, String word) {
		List<WordRatio> lstWR = getWordRatiosFromBlock(city, word);
		Collections.sort(lstWR);
		int size = 20 > lstWR.size() ? lstWR.size() : 20;
		List<WordRatio> lstRS = lstWR.subList(0, size);
		return lstRS;
	}

	public List<WordRatio> getWordsFromSell(String city, String word) {
		List<WordRatio> lstWR = getWordRatiosFromBlock(city, word);
		lstWR.addAll(getWordRatiosFromSchool(city, word));
		lstWR.addAll(getWordRatiosFromTraffic(city, word));
		Collections.sort(lstWR);
		int size = 20 > lstWR.size() ? lstWR.size() : 20;
		List<WordRatio> lstRS = lstWR.subList(0, size);
		return lstRS;
	}

	private List<WordRatio> getWordRatiosFromBlock(String city, String word) {
		Set<WordBean> wordBeans = blockLoader.getWordBeanByCity(city);
		if (wordBeans != null && !wordBeans.isEmpty()) {
			return findWordsByContains(word, wordBeans);
		}
		return new ArrayList<WordRatio>();
	}

	private List<WordRatio> getWordRatiosFromSchool(String city, String word) {
		Set<WordBean> wordBeans = schoolLoader.getWordBeanByCity(city);
		if (wordBeans != null && !wordBeans.isEmpty()) {
			return findWordsByContains(word, wordBeans);
		}
		return new ArrayList<WordRatio>();
	}

	private List<WordRatio> getWordRatiosFromTraffic(String city, String word) {
		Set<WordBean> wordBeans = trafficLoader.getWordBeanByCity(city);
		if (wordBeans != null && !wordBeans.isEmpty()) {
			return findWordsByContains(word, wordBeans);
		}
		return new ArrayList<WordRatio>();
	}

	public List<WordRatio> getWordsFromSellByEquals(String city, String word) {
		List<WordRatio> lstWR = getWordRatiosFromBlockByEquals(city, word);
		lstWR.addAll(getWordRatiosFromSchoolByEquals(city, word));
		lstWR.addAll(getWordRatiosFromTrafficByEquals(city, word));
		return lstWR;
	}

	private List<WordRatio> getWordRatiosFromBlockByEquals(String city,
			String word) {
		Set<WordBean> wordBeans = blockLoader.getWordBeanByCity(city);
		if (wordBeans != null && !wordBeans.isEmpty()) {
			return findWordsByEquals(word, wordBeans);
		}
		return new ArrayList<WordRatio>();
	}

	private List<WordRatio> getWordRatiosFromSchoolByEquals(String city,
			String word) {
		Set<WordBean> wordBeans = schoolLoader.getWordBeanByCity(city);
		if (wordBeans != null && !wordBeans.isEmpty()) {
			return findWordsByEquals(word, wordBeans);
		}
		return new ArrayList<WordRatio>();
	}

	private List<WordRatio> getWordRatiosFromTrafficByEquals(String city,
			String word) {
		Set<WordBean> wordBeans = trafficLoader.getWordBeanByCity(city);
		if (wordBeans != null && !wordBeans.isEmpty()) {
			return findWordsByEquals(word, wordBeans);
		}
		return new ArrayList<WordRatio>();
	}

	// 编辑距离计算
	// private List<WordRatio> findWordsByWordDis(String word, Set<WordBean>
	// dic) {
	// List<WordRatio> lstRs = new ArrayList<WordRatio>();
	// for (WordBean wordBean : dic) {
	// float dis = 0;
	// String lw = wordBean.getWord();
	// float dicLen = lw.length();
	// float myLen = word.length();
	// dis = DistanceCalculate.getWordDistance(word, lw);
	// float len = myLen > dicLen ? myLen : dicLen;
	// float matchSize = len - dis;
	// float matchRate = (matchSize / dicLen + matchSize / myLen) / 2;
	// if (matchRate > 0.2)
	// lstRs.add(new WordRatio(wordBean, matchRate));
	// }
	// return lstRs;
	// }
	public static boolean isChineseChar(String str) {
		boolean temp = false;
		Pattern p = Pattern.compile("[\u4e00-\u9fa5]");
		Matcher m = p.matcher(str);
		if (m.find()) {
			temp = true;
		}
		return temp;
	}

	private List<WordRatio> findWordsByContains(String word, Set<WordBean> dic) {
		List<WordRatio> lstRs = new ArrayList<WordRatio>();
		for (WordBean wordBean : dic) {
			String lw = wordBean.getWord();
			if (isChineseChar(word)) {
				if (lw.contains(word)) {
					float dicLen = lw.length();
					float myLen = word.length();
					float matchRate = myLen / dicLen;
					lstRs.add(new WordRatio(wordBean, matchRate));
				}
			} else {
				String dicPY = wordBean.getPinyin();
				if (StringUtils.isNotBlank(dicPY)) {
					String wordPY = PinyinToolkit.cn2Spell(word);
					// logger.info("wordPY:" + wordPY + " dicPY:" + dicPY);
					if (dicPY.startsWith(wordPY)) {
						float dicLen = dicPY.length();
						float myLen = wordPY.length();
						float matchRate = myLen / dicLen;
						lstRs.add(new WordRatio(wordBean, matchRate));
					}
				}
			}
		}
		return lstRs;
	}

	private List<WordRatio> findWordsByEquals(String word, Set<WordBean> dic) {
		List<WordRatio> lstRs = new ArrayList<WordRatio>();
		for (WordBean wordBean : dic) {
			String lw = wordBean.getWord();
			if (lw.equalsIgnoreCase(word)) {
				lstRs.add(new WordRatio(wordBean, 1.0f));
			}
		}
		return lstRs;
	}
}
