package com.house365.xxx.house.word.search.sell;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.springframework.stereotype.Component;

import com.house365.xxx.house.word.search.DicType;
import com.house365.xxx.house.word.search.dto.DistrictStreet;
import com.house365.xxx.house.word.search.dto.WordBean;
import com.house365.xxx.house.word.search.util.PinyinToolkit;

/**
 * 二手房社区
 */
@Component
public class CommunityLoader extends SellLoader {

	@Override
	protected DicType getDicType() {
		return DicType.COMMUNITY;
	}

	@Override
	protected String getLoadSql() {
	    return "SELECT\r\n" + 
	    		"	t_community.community_id,\r\n" + 
	    		"	t_community.community_name,\r\n" + 
	    		"	t_community.district,\r\n" + 
	    		"	t_community.streetname,\r\n" + 
	    		"	sum(\r\n" + 
	    		"		ifnull(t_block_count.sellcount, 0)\r\n" + 
	    		"	) AS sellcount,\r\n" + 
	    		"	sum(\r\n" + 
	    		"		ifnull(t_block_count.rentcount, 0)\r\n" + 
	    		"	) AS rentcount,\r\n" + 
	    		"	'' AS alias,\r\n" + 
	    		"	'' AS extinfo,\r\n" + 
	    		"	'' AS averPrice\r\n" + 
	    		"FROM\r\n" + 
	    		"	(\r\n" + 
	    		"		SELECT\r\n" + 
	    		"			t_community.id AS community_id,\r\n" + 
	    		"			t_community.community_name,\r\n" + 
	    		"			t_community.district,\r\n" + 
	    		"			t_street.streetname\r\n" + 
	    		"		FROM\r\n" + 
	    		"			community t_community\r\n" + 
	    		"		LEFT OUTER JOIN street t_street ON t_community.street = t_street.id\r\n" + 
	    		"		WHERE\r\n" + 
	    		"			t_community. STATUS = 1\r\n" + 
	    		"	) t_community\r\n" + 
	    		"LEFT OUTER JOIN block t_block ON t_community.community_id = t_block.community_id\r\n" + 
	    		"LEFT OUTER JOIN block_count t_block_count ON t_block.id = t_block_count.blockid\r\n" + 
	    		"GROUP BY\r\n" + 
	    		"	t_community.community_id,\r\n" + 
	    		"	t_community.community_name,\r\n" + 
	    		"	t_community.district,\r\n" + 
	    		"	t_community.streetname";
	}

	@Override
	protected Log getLogger() {
		return LogFactory.getLog(CommunityLoader.class);
	}

    @Override
    protected WordBean getWordBean(int id, String name, String pinyin, DicType dicType,
            DistrictStreet districtStreet, int sellCount, int rentCount, String alias, String extInfo, String averPrice) {
        WordBean wordBean = new WordBean(id, name, PinyinToolkit.cn2Spell(name), getDicType(),
                districtStreet, sellCount, rentCount, alias, extInfo, averPrice);
        return wordBean;
    }

}
