package com.house365.xxx.house.word.search.sell;

import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Set;

import javax.annotation.Resource;

import org.apache.commons.lang.StringUtils;
import org.apache.commons.logging.Log;

import com.house365.xxx.house.word.search.CityAndDBManager;
import com.house365.xxx.house.word.search.DicType;
import com.house365.xxx.house.word.search.db.MDbcpPoolHelper;
import com.house365.xxx.house.word.search.dto.DistrictStreet;
import com.house365.xxx.house.word.search.dto.WordBean;
import com.house365.xxx.house.word.search.util.PinyinToolkit;

public abstract class SellLoader {
	@Resource
	protected MDbcpPoolHelper dbcpPoolHelper;
	@Resource
	protected CityAndDBManager cityAndDB;
	protected HashMap<String, Set<WordBean>> mapCityWordBean = new HashMap<String, Set<WordBean>>();

	public Set<WordBean> getWordBeanByCity(String city) {
		return mapCityWordBean.get(city);
	}

	public void loadWordBeans(Set<String> citys) {
		for (String city : citys) {
			mapCityWordBean.remove(city);
			Connection con = null;
			PreparedStatement ps = null;
			ResultSet rs = null;
			try {
				con = dbcpPoolHelper.getConn(cityAndDB.getSellDBByCity(city));
				ps = con.prepareStatement(getLoadSql());
				rs = ps.executeQuery();
				while (rs.next()) {
					int id = rs.getInt(1);
					String name = rs.getString(2);
					String districtname = rs.getString(3);
					String streetname = rs.getString(4);
					DistrictStreet districtStreet = new DistrictStreet(districtname, streetname);
					int sellCount = rs.getInt(5);
					int rentCount = rs.getInt(6);
					String alias = rs.getString(7);
					String extInfo = rs.getString(8);
					String averPrice = rs.getString(9);
					if (StringUtils.isNotBlank(name)) {
					    WordBean wordBean = getWordBean(id, name, PinyinToolkit.cn2Spell(name), getDicType(), districtStreet, sellCount, rentCount, alias, extInfo, averPrice);
						if (mapCityWordBean.containsKey(city)) {
							mapCityWordBean.get(city).add(wordBean);
						} else {
							Set<WordBean> setWordBean = new HashSet<WordBean>();
							setWordBean.add(wordBean);
							mapCityWordBean.put(city, setWordBean);
						}
					}
				}
			} catch (SQLException e) {
			    getLogger().error("context city="+city);
				getLogger().error(e.getMessage(), e);
			} finally {
				dbcpPoolHelper.release(rs, ps, con);
			}
		}
	}

	protected abstract DicType getDicType();

	protected abstract String getLoadSql();

	protected abstract Log getLogger();

    protected abstract WordBean getWordBean(int id, String name, String pinyin, DicType dicType,
            DistrictStreet districtStreet, int sellCount, int rentCount, String alias, String extInfo, String averPrice);
}
