package com.house365.xxx.house.word.search.sell;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.springframework.stereotype.Component;

import com.house365.xxx.house.word.search.DicType;
import com.house365.xxx.house.word.search.dto.DistrictStreet;
import com.house365.xxx.house.word.search.dto.WordBean;
import com.house365.xxx.house.word.search.util.PinyinToolkit;

@Component
public class TrafficLoader extends SellLoader {

	@Override
	protected DicType getDicType() {
		return DicType.TRAFFIC;
	}

	@Override
	protected String getLoadSql() {
		return " SELECT\r\n" + 
				"	t.bid,\r\n" + 
				"	t.station,\r\n" + 
				"	'' AS districtname,\r\n" + 
				"	'' AS streetname,\r\n" + 
				"	t.sellcount,\r\n" + 
				"	t.rentcount,\r\n" + 
				"	'' AS alias,\r\n" + 
				"	t.line,\r\n" + 
				"	'' AS averPrice\r\n" + 
				"FROM\r\n" + 
				"	(\r\n" + 
				"		SELECT\r\n" + 
				"			t_traffic.bid,\r\n" + 
				"			t_traffic.station,\r\n" + 
				"			t_traffic.line,\r\n" + 
				"			sum(\r\n" + 
				"				ifnull(t_block_count.sellcount, 0)\r\n" + 
				"			) AS sellcount,\r\n" + 
				"			sum(\r\n" + 
				"				ifnull(t_block_count.rentcount, 0)\r\n" + 
				"			) AS rentcount\r\n" + 
				"		FROM\r\n" + 
				"			traffic t_traffic\r\n" + 
				"		LEFT OUTER JOIN traffic_block t_traffic_block ON t_traffic_block.bid = t_traffic.bid\r\n" + 
				"		LEFT OUTER JOIN block_count t_block_count ON t_block_count.blockid = t_traffic_block.blockid\r\n" + 
				"		WHERE\r\n" + 
				"			t_traffic.TYPE = 2\r\n" + 
				"		GROUP BY\r\n" + 
				"			t_traffic.bid,\r\n" + 
				"			t_traffic.station\r\n" + 
				"	) t";
	}

	@Override
	protected Log getLogger() {
		return LogFactory.getLog(TrafficLoader.class);
	}

    @Override
    protected WordBean getWordBean(int id, String name, String pinyin, DicType dicType,
            DistrictStreet districtStreet, int sellCount, int rentCount, String alias, String extInfo, String averPrice) {
        WordBean wordBean = new WordBean(id, name, PinyinToolkit.cn2Spell(name), getDicType(),
                districtStreet, sellCount, rentCount, alias, extInfo, averPrice);
        return wordBean;
    }

}
